@@ -4,15 +4,13 @@ Posts a comment to this project's bitbucket repository with 'build annotations'
 to encapsulate the inner-message with diff-markdown. To support the build annotations, this 
 script requires many parameters (most provided as environment variables, some as CLI arguments).
 '''
-import os
 import requests
-from json import loads
 from textwrap import dedent
 
-import configargparse
-
 from buildtools import util, __version__, BuildToolsTemplate
-from buildtools.util import BitbucketMarkdownComment
+from buildtools.util.markdown_comment_builder import BitbucketMarkdownComment
+from buildtools.util import split_markdown
+
 
 def create_comment(args, message):
     mc = BitbucketMarkdownComment()
@@ -22,7 +20,7 @@ def create_comment(args, message):
         mc.add_ansible_results(results)
     elif args.code_markdown:
         mc.add_code_markdown(message)
-    elif args.diff_markdown: # Should be mutex with code_markdown...
+    elif args.diff_markdown:  # Should be mutex with code_markdown...
         mc.add_diff_markdown(message)
     else:
         mc.add_message(message)
@@ -34,6 +32,7 @@ def create_comment(args, message):
         mc.add_build_annotation(args.build_id, args.build_url, args.playbook_limit, args.build_status)
     return str(mc)
 
+
 class PostBitbucketPRComment(BuildToolsTemplate):
     def __init__(self):
         cli_path = ['post', 'bitbucket', 'pr-comment']
@@ -64,13 +63,34 @@ class PostBitbucketPRComment(BuildToolsTemplate):
                 print(f"[ERROR] No such file: {args.comment_file}\n")
                 exit(-1)
 
+        if len(str(comment).strip()) == 0:
+            raise ValueError("Some comment contents must be provided -- the comment to be sent was an empty string.")
+
         # Actually make the request
         try:
-            response = requests.post(f'{args.bitbucket_url}/rest/api/1.0/projects/{args.project}/repos/{args.repo}/pull-requests/{args.pull_request_id}/comments',
-                json = {'text': comment if comment else '*Empty string provided.*'}, 
-                auth = (args.user, args.password)
-                )
-            response.raise_for_status()
+            # If the comment will exceed the max comment size, do fragmentation instead!
+            if args.max_comment_size and len(str(comment)) > args.max_comment_size:
+                comment_fragments = split_markdown(str(comment), args.max_comment_size)
+                # Comments are in reverse chronological, so we should render the fragments in reverse.
+                comment_fragments.reverse()
+                # cp_i => "Comment Part Index"
+                cp_i = len(comment_fragments)
+                for comment_part in comment_fragments:
+                    pagination_str = f'> Comment __{cp_i}__ of __{len(comment_fragments)}__.'
+                    msg = f'{pagination_str}\n{comment_part}'
+                    cp_i -= 1
+                    response = requests.post(
+                        f'{args.bitbucket_url}/rest/api/1.0/projects/{args.project}/repos/{args.repo}/pull-requests/{args.pull_request_id}/comments',
+                        json={'text': msg},
+                        auth=(args.user, args.password)
+                        )
+                    response.raise_for_status()
+            else:
+                response = requests.post(f'{args.bitbucket_url}/rest/api/1.0/projects/{args.project}/repos/{args.repo}/pull-requests/{args.pull_request_id}/comments',
+                    json = {'text': comment if comment else '*Empty string provided.*'},
+                    auth = (args.user, args.password)
+                    )
+                response.raise_for_status()
         except requests.exceptions.HTTPError as error:
             print(f"[ERROR] HTTP Error ({error.response.status_code}): {error.response.text}")
             exit(-1)
@@ -109,7 +129,9 @@ class PostBitbucketPRComment(BuildToolsTemplate):
             help='Clean/remove any ANSI Color codes that are in the provided message/file.')
         formatting.add('--code-markdown', action='store_true',
             help='Wrap the provided comment in code markdown. E.g. ```\n\{comment\})\n```')    
-        formatting.add('--tail', type=int, 
+        formatting.add('--max-comment-size', type=int,
+            help='Fragment the comment into based on the maximum comment size.')
+        formatting.add('--tail', type=int,
             help='Only print the last `TAIL` lines of the provided message/file.')    
         # Build Annotation (aka 'ba') parser.
         ba_parser = formatting.add_argument_group('Build Annotation')
