@@ -19,7 +19,7 @@ class PullRequestCard(TeamsCardTemplate):
     def build(self, args):
         # Calculate URLs for the pull request, based on args
         pull_request_url = f'{args.bitbucket_url}/projects/{args.project}/repos/{args.repo_slug}/pull-requests/{args.pull_request_id}'
-        pull_request_diff_url =  pull_request_url + "/diff"
+        pull_request_diff_url = pull_request_url + "/diff"
 
         # Set the title using a (module-level) helper method
         self.set_title(f"Pull Request {args.pull_request_id}: {args.pull_request_title}")
@@ -144,7 +144,7 @@ class TeamsCardFactory:
         if hasattr(args, 'clean_ansi_colors') and args.clean_ansi_colors:
             mc.clean_ascii_codes()
 
-        card.set_text(str(mc))
+        card.add_section(str(mc))
 
 
     @staticmethod
